@@ -197,12 +197,15 @@ class Seti():
 
     # Recharger
 
-    def create_recharger(self, value: int,  secret: str):
+    def create_recharger(self, value: int,  secret: str, custom_methods: List[str]):
         self.is_error = False
         self.validate_value(value)
+        self.validate_payment_method(custom_methods)
         data_create_recharger = {
             "value": value,
-            "secret": secret
+            "secret": secret,
+            "customMethods": custom_methods,
+
         }
         CREATE_RECHARGER_URL = "create-recharger"
         encode_data = self.sign_data(data_create_recharger)
